'use strict';

//环境IP地址
var ADDR = require('../business/BaseHost');
var ajax = require('./ajax');
var _ = require('lodash');
//图片读取为base64格式数据
function readImageAsBase64(item, callback) {
    if (!item || typeof item.getAsFile !== 'function') {
        return;
    }
    var file = item.getAsFile();
    var reader = new FileReader();
    reader.onload = function (evt) {
        callback(evt.target.result);
    };
    reader.readAsDataURL(file);
}

var PasteImageUtils = {};
/**
 * 获取粘贴图片数据
 * @param event window.event 对象
 * @param callback 获取粘贴图片的base64数据
 */
PasteImageUtils.getImageData = function (event, callback) {
    var clipboardData = event ? event.clipboardData : null;
    var found = false;
    var imageType = /^image/;
    if (!clipboardData) return;
    return Array.prototype.forEach.call(clipboardData.types, function (type, i) {
        if (found) return;
        if (type.match(imageType) || clipboardData.items[i].type.match(imageType)) {
            readImageAsBase64(clipboardData.items[i], callback);
            return found = true;
        }
    });
};

/**
 * 获取粘贴图片的img元素
 * @param event
 * @param callback
 */
PasteImageUtils.getImageDom = function (event, callback) {
    PasteImageUtils.getImageData(event, function (imgData) {
        var element = document.createElement('img');
        element.src = imgData;
        callback(element);
    });
};
/**
 * 粘贴图片到指定目标
 * @param event
 * @param callback
 */
PasteImageUtils.pasteTo = function (event, target) {
    PasteImageUtils.getImageDom(event, function (imgElement) {
        target.appendChild(imgElement);
    });
};

/**
 * 绑定图片粘贴事件
 * @param event
 * @param callback
 */
PasteImageUtils.bindPaste = function (target) {
    if (!target || !target.addEventListener) return;
    target.addEventListener('paste', function (event) {
        PasteImageUtils.pasteTo(event, this);
    });
};
/**
 * 压缩图片
 * @param img
 */
PasteImageUtils.zipImg = function (imgBase64, callback, options) {
    console.log('原始大小:' + imgBase64.length);
    var img = new Image();
    img.src = imgBase64;
    img.onload = function () {
        var canvas = document.createElement('CANVAS');
        var ctx = canvas.getContext('2d');
        var width = img.width;
        var height = img.height;
        // 按比例压缩4倍
        //var rate = (width<height ? width/height : height/width)/4;
        var rate = 0.9;
        if (width > 800 && height > 480) rate = 0.8;
        if (width > 900 && height > 600) rate = 0.75;
        if (width > 960 && height > 720) rate = 0.7;
        if (width > 1024 && height > 768) rate = 0.65;
        if (width > 1280 && height > 768) rate = 0.6;
        if (options && options.rate) rate = options.rate;
        canvas.width = width * rate;
        canvas.height = height * rate;
        ctx.drawImage(img, 0, 0, width, height, 0, 0, width * rate, height * rate);
        //var dataURL = canvas.toDataURL("image/png", 0.1);
        var dataURL = canvas.toDataURL("image/jpeg", 0.8);
        console.log('压缩后大小:' + dataURL.length);
        if (typeof callback == 'function') callback(dataURL);
        canvas = null;
    };
};
//ajax上传base64图片数据，上传成功后返回url
PasteImageUtils.uploadImg = function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { url: url, imgData: imgData, params: params, success: success, error: error };

    var opts = options ? options : {};
    //var xhr = new XMLHttpRequest(),
    //    fd  = new FormData();
    ////需要上传的图片base64数据
    //fd.append('content', opts.imgData.replace('data:image/png;base64,',''));
    ////附加的自定义参数
    //if(opts.params){
    //    for(var key in opts.params){
    //        fd.append(key, opts.params[key]);
    //    }
    //}
    ////请求URL
    //xhr.open('POST',opts.url?opts.url:ADDR+'/icop-file/file/uploadBase64',true);//第三个参数标识为异步请求
    ////请求回调
    //xhr.onload = function (){
    //    if(typeof options.success == 'function')options.success(xhr.responseText);
    //};
    ////发送请求
    //xhr.send(fd);
    var data = _.assign({}, opts.params, { content: opts.imgData.replace('data:image/png;base64,', '').replace('data:image/jpeg;base64,', '') });
    ajax.postJSON(opts.url ? opts.url : ADDR + '/icop-file/file/uploadBase64', data, opts.success, opts.error);
};
module.exports = PasteImageUtils;