'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * Created by Dio on 2016/5/11.
 */
var React = require('react');
var ReactDOM = require('react-dom');

var _require = require('antd'),
    Tooltip = _require.Tooltip,
    Icon = _require.Icon;

var YYClass = require('../base/YYClass');
var rowSelection = require('./rowSelection');
var YYTableCol = require('./YYTableCol');
var Table = require('./override/AntdTable');
var _ = require('lodash');

var uiMetaFields = require('./uiMetaFields');
var DomUtils = require('./utils/DomUtils');
var ResizerLine = require('./ResizerLine');
var DataUtil = require('../../utils/DataUtil');
var TreeUtils = require('../../utils/TreeUtils');
var EventUtils = require('../../utils/EventUtils');
var UrlUtils = require('../../utils/UrlUtils');
var formatUtils = require('../../utils/formatUtils');
var MathX = require('../../utils/matheval/formula_evaluator');
var YYTitleGroup = require('./YYTitleGroup');
var YYColumnTotals = require('./YYColumnTotals');
var YYModal = require('../modal/YYModal');
var confirm = YYModal.confirm;
// var YYMessage = require('./../message/YYMessage');
var YYInput = require('../formcontrols/input/YYInput');
var PAGE_SIZE_LOCAL_KEY = '_YYTABLE_PAGE_SIZE_'; //本地记录切换后的每页显示数
var PAGE_NUMBER_LOCAL_KEY = '_YYTABLE_PAGE_NUMBER_'; // 本地记录当前页码
var PAGE_NUMBER_LOCAL_KEY_EXPIRY = '_YYTABLE_PAGE_NUMBER_EXPIRY_'; // 本地记录当前页码有效期

var YYPopMenu = require('../popmenu/YYPopMenu');
var ColumnConfigUtils = require('./utils/ColumnConfigUtils');
var YYColumnConfig = require('./YYColumnConfig');
var YYTableRowMenu = require('./YYTableRowMenu');

var _require2 = require('rc-table/lib/utils'),
    measureScrollbar = _require2.measureScrollbar;

require('./style/index.less');

var prefixTableColCls = 'yyui-table-col'; //表格列类前缀
var prefixTableGroupColCls = 'yyui-table-groupcol'; //多表头合并列类前缀

//定义META
var uiMeta = {
    name: 'table',
    fields: uiMetaFields
};
//获取默认的cookiekey
function getDefaultCookieKey(props) {
    if (!props || !_.isPlainObject(props)) {
        return '';
    }

    var _ref = props || {},
        cookieKey = _ref.cookieKey,
        uikey = _ref.uikey;

    var _ref2 = props.uiorigin || {},
        pageCode = _ref2.pageCode;

    if (cookieKey) {
        return cookieKey;
    } else {
        //未配置cookieKey时，如果是界面设计器的页面则默认生成pageCode+uiKey作为cookieKey.
        if (pageCode && uikey) {
            return pageCode + uikey;
        }
    }
    return '';
}
//获取默认的分页数
function getDefaultPageSize(key) {
    var pageSize = DataUtil.localRead(PAGE_SIZE_LOCAL_KEY + (key ? key : '')); //读取本地记录的每页显示数
    return pageSize ? parseInt(pageSize) : 10;
}
//获取当前页码
function getCurrentPageNumber(key) {
    var pageNumber = DataUtil.localRead(PAGE_NUMBER_LOCAL_KEY + (key ? key : '')); //读取本地记录的当前页码
    return pageNumber ? parseInt(pageNumber) : 1;
}
function getCurrentPageNumberExpiry(key) {
    var pageNumber = DataUtil.localRead(PAGE_NUMBER_LOCAL_KEY_EXPIRY + (key ? key : '')); //读取本地记录的当前页码有效期
    return pageNumber ? parseInt(pageNumber) : 1;
}
// 设置本地每页显示条数
function setLocalPageSize(key, pageSize) {
    DataUtil.localSave(PAGE_SIZE_LOCAL_KEY + (key ? key : ''), pageSize);
}
// 获取本地缓存的每页显示数
function getLocalPageSize(key) {
    var pageSize = DataUtil.localRead(PAGE_SIZE_LOCAL_KEY + (key ? key : ''));
    return pageSize ? parseInt(pageSize) : undefined;
}
// 运行计算公式
function mathFormulaResult(mathFormula, rowData, defaultValue) {
    var formula = '' + mathFormula;
    _.forIn(rowData, function (value, key) {
        formula = formula.replace(new RegExp('{' + escape(key) + '}', 'gm'), escape(value));
    });
    try {
        var result = MathX.eval(formula);
        // 判断计算结果是否为数值类型
        if (new RegExp("(^[0-9]+\.?[0-9]*$)|(^\-[0-9]+\.?[0-9]*$)").test(result)) {
            result = _.toNumber(result);
        } else {
            result = 0;
        }
        return result;
    } catch (error) {
        // console.error('[公式计算出错]',{formula,mathFormula,rowData,error});
    }
    return defaultValue;
};
var YYTable = YYClass.create({
    uiMeta: uiMeta,
    getInitialState: function getInitialState() {
        var columns = this._getColumnsFromColumnsOrChilldren(this.props.columns, this.props.children);
        var columnsBackup = _.cloneDeep(columns);
        // BEGIN xg modified 新增从缓存读取表格列配置逻辑

        var _ref3 = this.props.uiorigin || {},
            pageCode = _ref3.pageCode;

        var mixedColumns = ColumnConfigUtils.combineColumnConfigs({ columns: columns, pageCode: pageCode, tableKey: this.props.uikey, cookieKey: this.props.cookieKey });
        var cachedScroll = ColumnConfigUtils.getCachedTableScroll({ pageCode: pageCode, tableKey: this.props.uikey, cookieKey: this.props.cookieKey });
        // END
        return {
            columns: this._renderColumns(mixedColumns, null, this.props),
            columnsBackup: columnsBackup, // 初始表格列的备份(未与缓存混淆时的设计态表格列配置)
            rowActiveKey: this.props.rowActiveKey, //当前高亮状态的行
            showColumnConfigModal: false, // 是否显示表格列配置
            isTitleGroup: false,
            scroll: cachedScroll && !_.isEmpty(cachedScroll) ? cachedScroll : this.props.scroll // 垂直方向的滚动条
        };
    },
    statics: {
        rowSelection: rowSelection,
        cloumns: YYTableCol,
        PAGE_NUMBER_LOCAL_KEY: PAGE_NUMBER_LOCAL_KEY,
        PAGE_NUMBER_LOCAL_KEY_EXPIRY: PAGE_NUMBER_LOCAL_KEY_EXPIRY,
        PAGE_SIZE_LOCAL_KEY: PAGE_SIZE_LOCAL_KEY,
        getDefaultCookieKey: getDefaultCookieKey, //获取默认的cookieKey
        getDefaultPageSize: getDefaultPageSize, //获取默认的分页数
        setLocalPageSize: setLocalPageSize, //设置本地每页显示条数
        getLocalPageSize: getLocalPageSize, //获取本地每页显示条数
        refTitleGroupIndex: 0
        //获取默认的cookiekey
    }, _getDefaultCookieKey: function _getDefaultCookieKey() {
        return getDefaultCookieKey(this.props);
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {

        if ('rowActiveKey' in nextProps) {
            this.setState({ rowActiveKey: nextProps.rowActiveKey });
        }
        if ('columns' in nextProps || 'children' in nextProps) {
            // BEGIN xg modified 新增从缓存读取表格列配置逻辑
            var columns = this._getColumnsFromColumnsOrChilldren(nextProps.columns, nextProps.children, nextProps);
            var columnsBackup = _.cloneDeep(columns);

            var _ref4 = nextProps.uiorigin || {},
                pageCode = _ref4.pageCode;

            var mixedColumns = ColumnConfigUtils.combineColumnConfigs({ columns: columns, pageCode: pageCode, tableKey: nextProps.uikey, cookieKey: nextProps.cookieKey });
            this.setState({ columns: this._renderColumns(mixedColumns, null, nextProps), columnsBackup: columnsBackup });
            // END
        }
        if (nextProps.columns !== this.props.columns) {
            delete this.isAnyColumnsFixedCache;
            delete this.isAnyColumnsLeftFixedCache;
            delete this.isAnyColumnsRightFixedCache;
            delete this.isAnyColumnsTotalCache;
            delete this.isAnyColumnsInnerFilterCache;
            delete this.isAnyColumnsGroupCache;
        }
        if ('scroll' in nextProps && nextProps.scroll !== this.props.scroll) {
            var _ref5 = nextProps.uiorigin || {},
                pageCode = _ref5.pageCode;

            var cachedScroll = ColumnConfigUtils.getCachedTableScroll({ pageCode: pageCode, tableKey: nextProps.uikey, cookieKey: nextProps.cookieKey });
            this.setState({ scroll: cachedScroll && !_.isEmpty(cachedScroll) ? cachedScroll : nextProps.scroll });
        }
    }
    //当每页分页数发生变更时
    , _onShowSizeChange: function _onShowSizeChange(current, pageSize) {
        DataUtil.localSave(PAGE_SIZE_LOCAL_KEY + this._getDefaultCookieKey(), pageSize); //本地记录每页显示数
        DataUtil.localSave(PAGE_NUMBER_LOCAL_KEY + this._getDefaultCookieKey(), current); //本地记录当前页码
        DataUtil.localSave(PAGE_NUMBER_LOCAL_KEY_EXPIRY + this._getDefaultCookieKey(), new Date(Date.now() + 1000 * 60 * 30).getTime()); //本地记录当前页码有效期
        if (this.props.pagination && _.isFunction(this.props.pagination.onShowSizeChange)) {
            this.props.pagination.onShowSizeChange(current, pageSize);
        }
    }
    // 当页码发生变更时
    , _onPageNumberChange: function _onPageNumberChange(current) {
        DataUtil.localSave(PAGE_NUMBER_LOCAL_KEY + this._getDefaultCookieKey(), current); //本地记录当前页码
        DataUtil.localSave(PAGE_NUMBER_LOCAL_KEY_EXPIRY + this._getDefaultCookieKey(), new Date(Date.now() + 1000 * 60 * 30).getTime()); //本地记录当前页码有效期
        if (this.props.pagination && _.isFunction(this.props.pagination.onChange)) {
            this.props.pagination.onChange(current);
        }
    }
    //默认的分页配置
    , getDefaultPagination: function getDefaultPagination() {
        if (this.props.pagination == false) return false;
        var pageSize = getDefaultPageSize(this._getDefaultCookieKey()); //读取本地记录的每页显示数
        //存在指定值则使用指定值
        if (this.props.pagination && this.props.pagination.pageSize) {
            pageSize = this.props.pagination.pageSize;
        }
        var p = {
            showQuickJumper: true, size: 'default',
            showSizeChanger: true,
            pageSizeOptions: [10, 30, 50, 100, 200, 500, 1000],
            showTotal: function showTotal(total) {
                return '\u5171 ' + total + ' \u6761';
            }
        };
        var otherProps = { onChange: this._onPageNumberChange, onShowSizeChange: this._onShowSizeChange };
        if (pageSize && !isNaN(parseInt(pageSize))) otherProps.pageSize = parseInt(pageSize);
        return _.assign(p, this.props.pagination, otherProps);
    }
    //默认的勾选配置
    , getDefaultRowSelection: function getDefaultRowSelection() {
        var rowSelection;
        if (this.props.checkable) {
            rowSelection = { type: 'checkbox' };
        };
        if (this.props.checkable !== false && this.props.rowSelection) {
            if (rowSelection) {
                rowSelection = _.assign(rowSelection, this.props.rowSelection);
            } else {
                rowSelection = this.props.rowSelection;
            }
            // //如果点击行时触发勾选效果 覆盖onChange
            // if(this.props.rowClickCheckable) {
            //     rowSelection.onChange = this._onSelectedRowChange(rowSelection);
            // }
        }
        return rowSelection;
    }
    //是否启用了多选模式
    , isEnableCheckable: function isEnableCheckable() {
        var rowSelection = this.getDefaultRowSelection();
        return rowSelection && (rowSelection.type == undefined || rowSelection.type == 'checkbox');
    }
    // 配置列 是否显示 显示顺序
    , _resolveData: function _resolveData(columns) {
        if (!_.isArray(columns) || columns.length == 0) return columns; //返回原始值
        // 排除 isShow == false 的项
        var columnsShow = _.filter(columns, function (column) {
            if (!column || column.isShow == undefined) return true;
            return column.isShow === false ? false : true; //只有为false则排除
        });

        // 排除 showIndex == undefiend 的项
        var columnWithOutShowIndex = [];
        var columnsWithShowIndex = _.filter(columnsShow, function (column) {
            if (!column) return true;
            if (column.showIndex == undefined) {
                columnWithOutShowIndex.push(column);
            }
            return column.showIndex != undefined;
        });
        // 依据showIndex进行排序
        var columnsSort = columnsWithShowIndex.sort(function (col1, col2) {
            return col1.showIndex - col2.showIndex;
        });
        // 加入 showIndex == undefined 的项, 处理title
        return columnsSort.concat(columnWithOutShowIndex);
    }
    //处理外部的column.render方法，克隆形成新的columns集合
    , _cloneColumns: function _cloneColumns(columns) {
        var newColumns = _.cloneDeep(columns);
        for (var i = 0; i < newColumns.length; i++) {
            var col = newColumns[i];
            if (_.isFunction(col.render)) {
                //将外部的render方法改为_outRender方法
                col._outRender = col.render;
                delete col.render;
            }
        }
        return newColumns;
    }
    //渲染render回调处理
    , _callbackColumns: function _callbackColumns(columns) {
        var _props = this.props,
            rowMenus = _props.rowMenus,
            rowMenuIconFont = _props.rowMenuIconFont,
            rowMenuIndex = _props.rowMenuIndex,
            onRowMenuClick = _props.onRowMenuClick;

        var lastColumn = columns[columns.length - 1];
        var rowMenuIndexKey = rowMenuIndex ? rowMenuIndex : lastColumn ? lastColumn.dataIndex || lastColumn.key : "";
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            col.render = function (text, record, index) {
                var thisCol = this;
                text = text == 'null' ? '' : text;
                var cellProps = {}; //当前单元格的属性
                var cellText = text; //当前单元格的文本
                //日期格式化
                if (thisCol.format && typeof cellText == 'number') {
                    if (/^[y|Y]{1,4}$/.test(thisCol.format)) {//只显示年份
                        //无需处理
                    } else {
                        var cellDate = new Date();
                        cellDate.setTime(cellText);
                        cellText = formatUtils.formatDate(cellDate, thisCol.format);
                    }
                }
                //运行计算公式
                if (thisCol.mathFormula) {
                    cellText = mathFormulaResult(thisCol.mathFormula, record, cellText);
                }
                //数字类型默认格式化显示千分位,注意cellText=0的情况
                if (typeof cellText === 'number' || cellText) {
                    var getDecimalConf = function getDecimalConf(str, colProps) {
                        //解析小数位配置
                        var numText = (str + "").split("."); //目前实际小数位
                        var nowDecimal = numText.length == 2 ? numText[1].length : 0; //当前实际的小数位
                        var decimal = nowDecimal;
                        if (colProps.decimal >= 0) decimal = colProps.decimal; //保留精确的小数位，如果不存在定义则精确为实际小数位（即悬浮显示的小数位）
                        var showDecimal = isNaN(parseInt(colProps.showDecimal)) ? decimal : colProps.showDecimal; //显示的小数位，如果不存在则按精确小数位进行显示
                        return { nowDecimal: nowDecimal, decimal: decimal, showDecimal: showDecimal };
                    };
                    if (thisCol.fieldtype == 'number') {
                        //整数
                        cellText = formatUtils.formatNumber(cellText, 0, thisCol.comma === false ? 0 : 3); //格式化千分位，省略小数位
                    } else if (thisCol.fieldtype == 'currency') {
                        var numConf = getDecimalConf(cellText, thisCol);
                        var cellDecimalText = formatUtils.formatNumber(cellText, numConf.decimal, thisCol.comma === false ? 0 : 3, null, thisCol.zeroFilling); //格式化千分位
                        cellProps.title = cellDecimalText;
                        if (thisCol.uisubtype == "currency" && record.isEdit) {//编辑表格+编辑态
                        } else {
                            //数据表格||编辑表格+非编辑态
                            var cellShowDecimalText = formatUtils.formatNumber(cellText, numConf.showDecimal, thisCol.comma === false ? 0 : 3, null, thisCol.zeroFilling); //格式化千分位
                            cellText = cellShowDecimalText;
                        }
                    }
                }
                //执行外部render回调
                if (thisCol._outRender) {
                    cellText = thisCol._outRender(cellText, record, index);
                }

                //处理字体颜色
                if (thisCol.color) {
                    if (typeof thisCol.color == 'function') {
                        var cellColor = thisCol.color(cellText, record, index);
                        if (cellColor) cellProps.style = { color: cellColor };
                    } else {
                        cellProps.style = { color: thisCol.color };
                    }
                }
                var cell,
                    cellObj = false;
                if (React.isValidElement(cellText) //外部自定义cell为react对象
                || _.isArray(cellText) //外部自定义cell为react数组对象
                ) {
                        cell = cellText;
                    } else {
                    if (_.isObject(cellText)) {
                        //外部自定义为{}对象，例如在处理行合并时。
                        cell = cellText;
                        cellObj = true;
                    } else {
                        if (cellText) {
                            //处理单元格内容文本过长时的悬浮title
                            if (!cellProps.title) cellProps.title = cellText;
                            cell = React.createElement('span', cellProps, cellText);
                        } else {
                            cellProps.dangerouslySetInnerHTML = { __html: '&nbsp;' }; //显示空格
                            cell = React.createElement('span', cellProps);
                        }
                    }
                }
                //处理链接URL
                if (thisCol.linkUrl && cellObj == false) {
                    var linkUrl = UrlUtils.fillUrlParams(thisCol.linkUrl, record);
                    var aProps = { href: linkUrl };
                    if (thisCol.linkType == '_blank') {
                        aProps.target = '_blank';
                    }
                    cell = React.createElement('a', aProps, cell);
                }
                //处理行操作菜单
                if (rowMenus && rowMenus.length) {
                    if (thisCol.dataIndex === rowMenuIndexKey || thisCol.key === rowMenuIndexKey) {
                        return [cell, React.createElement(YYTableRowMenu, {
                            record: record,
                            iconFont: rowMenuIconFont,
                            rowIndex: index,
                            rowMenus: rowMenus,
                            onRowMenuClick: onRowMenuClick
                        })];
                    } else {
                        return cell;
                    }
                } else {
                    return cell;
                }
            }.bind(col);
        }
        return columns;
    }
    //渲染行号列
    , _appendRowNumColumns: function _appendRowNumColumns(columns, currProps) {
        //是否配置显示行序号列
        if (currProps && currProps.showRowNum !== true) return columns;
        var isFixed = false;
        //处理显示固定列
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.isShow !== false && col.fixed == 'left') {
                isFixed = true;break;
            }
        }
        var numCol = {
            key: 'rowNum',
            dataIndex: 'rowNum',
            className: 'ant-table-rownum',
            fixed: 'left',
            title: '序号',
            isShow: currProps.visibleRowNum === undefined ? true : currProps.visibleRowNum
        };
        //如果存在左固定列则序号也显示为左固定列
        if (isFixed) numCol.fixed = 'left';
        //防止重复添加固定列配置
        if (!_.find(columns, ['key', 'rowNum'])) columns.unshift(numCol);
        return columns;
    }
    //渲染处理column.title为YYTitleGroup
    , _titleGroupColumns: function _titleGroupColumns(columns) {
        var _this2 = this;

        function onOrderChange(_ref6) {
            var sortColumn = _ref6.sortColumn,
                sortOrder = _ref6.sortOrder;

            this.refAntdTable.toggleSortOrder(sortOrder, sortColumn);
        }
        this.refTitleGroupIndex = 0;
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.colSpan > 0 && !_.isEmpty(col.titleGroup)) {
                //处理分组标题
                //获取被合并的可见列信息
                var groupColumns = [];
                var groupColumnsSpan = 0;
                for (var colSpanIdx = i; colSpanIdx < columns.length; colSpanIdx++) {
                    var colSpanColumn = columns[colSpanIdx];
                    if (colSpanColumn && colSpanColumn.isShow !== false) {
                        groupColumns.push(colSpanColumn);
                        groupColumnsSpan++;
                    }
                    if (groupColumnsSpan == col.colSpan) break;
                }
                //构建多表头末级节点与数据列定义之间的映射关系refDataIndex
                ColumnConfigUtils.groupRefDataIndex(col.titleGroup, groupColumns);
                col.title = React.createElement(YYTitleGroup, { ref: function ref(t) {
                        _this2['refTitleGroup-' + ++_this2.refTitleGroupIndex] = t;
                    }, group: col.titleGroup, columns: groupColumns, onOrderChange: onOrderChange.bind(this) });
                col.className = 'yyui-titlegroup-box ' + (col.className ? col.className : '');
            } else {
                if (_.isString(col.title)) {
                    //确保title为string类型
                    //处理超长标题的title
                    col.title = [React.createElement('span', { title: col.title }, col.title)];
                    //表头标题提示图标
                    if (col.titleTip) {
                        col.title.push(React.createElement(
                            Tooltip,
                            { title: col.titleTip },
                            React.createElement(Icon, { type: 'question-circle-o' })
                        ));
                    }
                }
            }
        }
        return columns;
    }
    //为列追加特殊类名，支持拖拽时追加dataIndex类名，存在align则追加文本对齐类名，存在required则追加必填类名。
    , _addColClass: function _addColClass(columns) {
        var _props2 = this.props,
            draggable = _props2.draggable,
            dataSource = _props2.dataSource;
        //是否为树形表格

        var isTreeTable = dataSource && dataSource.some(function (record) {
            return record.children;
        });
        var isTreeCls = false;
        return _.map(columns, function (column) {
            var _column = column,
                className = _column.className,
                dataIndex = _column.dataIndex,
                align = _column.align,
                titleAlign = _column.titleAlign,
                fieldtype = _column.fieldtype,
                isShow = _column.isShow,
                required = _column.required,
                colSpan = _column.colSpan,
                titleGroup = _column.titleGroup;

            var resultCls = className ? [className] : [];
            //确保显示列的第一个列，添加树形图标的样式名
            if (isShow !== false && isTreeTable && isTreeCls === false) {
                resultCls.push('has-expand-icon');
                isTreeCls = true;
            }
            if (draggable) {
                resultCls.push(prefixTableColCls + '-' + dataIndex);
            }
            if (required && !(colSpan > 0 && !_.isEmpty(titleGroup))) {
                //排除多表头的必填样式
                resultCls.push('title-required');
            }
            if (titleAlign == 'right') {
                //处理titleAlign对齐属性
                resultCls.push('title-right');
            } else if (titleAlign == 'center') {
                resultCls.push('title-center');
            }
            if (align == 'right') {
                //处理align对齐属性
                resultCls.push('text-right');
            } else if (align == 'center') {
                resultCls.push('text-center');
            } else if (align == 'left') {
                //默认左对齐
            } else {
                //未明确指定对齐方式
                //如果是数字或精确数值则默认右对齐
                if (fieldtype == 'number' || fieldtype == 'currency') {
                    resultCls.push('text-right');
                }
            }
            if (resultCls) {
                column = _.assign(column, { className: resultCls.length ? resultCls.join(" ") : null });
            }
            return column;
        });
    }
    //存在children则从children对象集合中解析出columns简单对象结构，否则直接读取columns简单对象结构
    , _getColumnsFromColumnsOrChilldren: function _getColumnsFromColumnsOrChilldren(columns, children) {
        var _columns = [];
        if (_.isArray(children) && children.length > 0) {
            _.forEach(children, function (child) {
                if (React.isValidElement(child)) {
                    //一般为YYTableCol对象
                    var column = _.assign({}, child.props);
                    if (child.key) column.key = child.key; //获取key值
                    _columns.push(column);
                }
            });
        } else {
            _columns = _.isArray(columns) ? columns : [];
        }
        return _columns;
    },
    _appendDefaultSortColumns: function _appendDefaultSortColumns(columns) {
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.sorterEnable && col.sorter === undefined && (col.colSpan !== 0 || col.colSpan === undefined) && !col.titleGroup) {
                columns[i]['sorter'] = ColumnConfigUtils.defaultSortColumnsFun(col);
            }
        }
        return columns;
    }
    //渲染列定义
    , _renderColumns: function _renderColumns(columns, children, currProps) {
        var _columns = this._getColumnsFromColumnsOrChilldren(columns, children);
        _columns = this._appendRowNumColumns(_columns, currProps); //追加行序号列
        _columns = this._resolveData(_columns); //处理isShow|showIndex
        _columns = this._cloneColumns(_columns); //处理外部column.render为column._outRender
        _columns = this._appendDefaultSortColumns(_columns); //追加预制排序
        _columns = this._titleGroupColumns(_columns); //处理titleGroup
        _columns = this._callbackColumns(_columns); //处理cell的文字的color和过长悬浮title信息、链接URL
        _columns = this._addColClass(_columns); //处理cell的column.className,为其追加一个dataindex所指定的classname，如果YYTable，draggable=true时添加，处理align对齐样式，处理required必填样式
        return _columns;
    }
    //获取行数据rowkey值
    , _getRowPrimaryValue: function _getRowPrimaryValue(record) {
        var rowPrimaryValue = '';
        if (typeof this.props.rowKey === 'function') {
            rowPrimaryValue = this.props.rowKey(record);
        } else {
            //rowKey是普通字符串
            var rowKey = this.props.rowKey ? this.props.rowKey : 'key';
            rowPrimaryValue = record[rowKey];
        }
        return rowPrimaryValue;
    },
    dealData: function dealData(data) {
        var arr = [];
        for (var i = 0; i < data.length; i++) {
            var row = data[i];
            arr.push(row);
            if (Array.isArray(row.children) && row.children.length > 0) {
                var subArr = this.dealData(row.children);
                arr = arr.concat(subArr);
            }
        }
        return arr;
    }
    //处理行选择样式
    , _onRowClick: function _onRowClick(record, index) {
        var _this3 = this;

        var onRowClick = this.props.onRowClick;
        var rowActiveKey = '';
        var rowPrimaryValue = this._getRowPrimaryValue(record);
        if (rowPrimaryValue) {
            if (rowPrimaryValue !== this.state.rowActiveKey) {
                rowActiveKey = rowPrimaryValue;
            } else if (this.state.rowActiveKey && rowPrimaryValue == this.state.rowActiveKey) {
                rowActiveKey = ''; //重复选择相同行时，取消选中状态
            }
        }
        this.setState({ rowActiveKey: rowActiveKey }, function () {
            if (_.isFunction(onRowClick)) {
                onRowClick(record, index, rowActiveKey);
            }
        });

        //多选模式并且启用的行点击关联勾选框
        if (this.isEnableCheckable()) {
            var rowSelection = this.getDefaultRowSelection();
            //如果定义了getCheckboxProps
            var checkboxProps = {};
            if (rowSelection && _.isFunction(rowSelection.getCheckboxProps)) {
                checkboxProps = rowSelection.getCheckboxProps(record);
            }
            //勾选模式下：选中行的同时处理行勾选状态
            if (checkboxProps.disabled !== true && this.props.rowClickCheckable) {
                // var selectedRowKeys = this.state.selectedRowKeys ? this.state.selectedRowKeys :[];
                // this.setState({selectedRowKeys:selectedRowKeys},function(){
                //执行onChange回调
                if (rowSelection) {
                    //获取勾选行的数据
                    var selectedRowKeys = rowSelection.selectedRowKeys ? _.cloneDeep(rowSelection.selectedRowKeys) : [];
                    var isInclude = _.includes(selectedRowKeys, rowPrimaryValue);
                    if (isInclude) {
                        selectedRowKeys = _.remove(selectedRowKeys, function (key) {
                            return key !== rowPrimaryValue;
                        });
                    } else {
                        selectedRowKeys.push(rowPrimaryValue);
                    }
                    var seletedRows = [];
                    var data = this.dealData(this.props.dataSource);
                    _.forEach(selectedRowKeys, function (key) {
                        for (var i = 0; i < data.length; i++) {
                            //可能存在翻页的情况，selectedRowKeys的值是正确的，dataSource有可能只有当前页的数据而导致rowData为空
                            var rowData = data[i];
                            var primaryValue = _this3._getRowPrimaryValue(rowData);
                            if (rowData && key == primaryValue) {
                                seletedRows.push(rowData);
                                break;
                            }
                        }
                    });
                    //执行外部onChange
                    if (_.isFunction(rowSelection.onChange)) {
                        rowSelection.onChange(selectedRowKeys, seletedRows);
                    }
                    //执行外部onSelect
                    if (_.isFunction(rowSelection.onSelect)) {
                        //多选情况时selected需要由isInclude参数判断
                        rowSelection.onSelect(record, !isInclude, seletedRows);
                    }
                }
            }
        }
    }
    //行选中的激活样式
    , _rowClassName: function _rowClassName(record, index) {
        var rowActiveKey = this.state.rowActiveKey;
        var rowCls = [];
        var rowPrimaryValue = this._getRowPrimaryValue(record);
        if (rowActiveKey && rowActiveKey === rowPrimaryValue) {
            //当前激活行高亮
            rowCls.push(this.className('row-selected'));
        }
        var rowClassName = this.props.rowClassName;
        if (_.isFunction(rowClassName)) {
            rowCls.push(rowClassName(record, index));
        }
        return rowCls.length > 0 ? rowCls.join(' ') : '';
    }
    //绑定表格行双击事件
    , _rowDoubleClick: function _rowDoubleClick() {
        var domRows = ReactDOM.findDOMNode(this).querySelectorAll('.ant-table-tbody .ant-table-row');
        var dataRows = this.props.dataSource;
        var rowDbClick = this.props.onRowDoubleClick;
        var pagination = this.getDefaultPagination();
        var pageNumber = getCurrentPageNumber(this._getDefaultCookieKey()); //读取当前的页码;
        var pageSize = pagination.pageSize;
        var that = this;
        if (domRows && domRows.length > 0) {
            _.forEach(domRows, function (tr, index) {
                var rowIndex = pageNumber * pageSize < dataRows.length ? index % pageSize : index % (dataRows.length <= pageSize ? dataRows.length : dataRows.length - pageSize * (pageNumber - 1));
                var rowData = dataRows && rowIndex < dataRows.length ? dataRows[rowIndex] : undefined;
                //解决前端分页情况下双击的数据索引问题
                if (pageNumber != undefined && pageSize != undefined) {
                    var pageRowIndex = (pageNumber > 0 ? pageNumber - 1 : 0) * pageSize + rowIndex;
                    if (pageRowIndex < dataRows.length) {
                        rowData = dataRows[pageRowIndex];
                    }
                }
                //绑定行双击事件
                tr.ondblclick = function (options) {
                    var rowData = options.rowData,
                        rowIndex = options.rowIndex,
                        pageNumber = options.pageNumber,
                        pageSize = options.pageSize;
                    //console.log('ondblclick------------>',dataRows[index]);

                    if (rowDbClick) {
                        rowDbClick(rowData, rowIndex, pageNumber, pageSize);
                    }
                }.bind(that, { rowData: rowData, rowIndex: rowIndex, pageNumber: pageNumber, pageSize: pageSize });
            });
        }
    }
    //绑定表格右键点击事件
    , _onmouseRightClick: function _onmouseRightClick() {
        var domTable = ReactDOM.findDOMNode(this);
        var headDoms = domTable.querySelectorAll('thead.ant-table-thead');
        var that = this;
        if (headDoms && headDoms.length) {
            _.forEach(headDoms, function (headDom) {
                headDom.oncontextmenu = function (event) {
                    var cookieKey = this._getDefaultCookieKey();
                    if (!cookieKey) {
                        console.warn('自定义列配置无法生效(pageCode或cookieKey不存在)');
                        return;
                    }
                    //解决超出屏幕底部的高度（弹出菜单被遮挡的问题）
                    var overSize = event.clientY + 3 * 36 - window.innerHeight;
                    //弹出右键菜单项
                    this._tablecontextmenu.show(event, {}, event.clientX, overSize > 0 ? event.clientY - overSize - 5 : event.clientY);
                    EventUtils.stopBubble(event);
                }.bind(that);
            });
        }
    }
    //右键菜单点击事件
    , _onContextMenuClick: function _onContextMenuClick(event, node) {
        var menuKey = event.key;
        if (menuKey == 'tableContextMenuConfigColumns') {
            //自定义列配置
            // if(this.isAnyColumnsGroup()){ // 多表头暂不支持自定义列配置
            //     YYMessage.error("多表头的表格暂不支持自定义配置",3);
            //     return;
            // }
            this.setState({ showColumnConfigModal: true, isTitleGroup: this.isAnyColumnsGroup() });
            // this.setState({showColumnConfigModal: true})
        }
    }
    //绑定事件
    , _bindEvent: function _bindEvent() {
        this._rowDoubleClick();
        this._onmouseRightClick();
    }
    // BEGIN xg add 表格列配置事件处理
    , _onColumnConfigDone: function _onColumnConfigDone(columnConfigs, scroll) {
        var _ref7 = this.props.uiorigin || {},
            pageCode = _ref7.pageCode;

        var options = { columns: this.state.columnsBackup, columnConfigs: columnConfigs, pageCode: pageCode,
            tableKey: this.props.uikey, cookieKey: this.props.cookieKey, scroll: scroll };
        var targetColumns = ColumnConfigUtils.columnConfigDone(options);
        targetColumns = this._renderColumns(targetColumns, null, this.props);
        this.setState({ columns: targetColumns, showColumnConfigModal: false, scroll: scroll });
    },
    _onColumnConfigCancel: function _onColumnConfigCancel() {
        this.setState({ showColumnConfigModal: false });
    },
    _onColumnConfigRevert: function _onColumnConfigRevert() {
        var _this = this;
        confirm({
            title: '确认',
            content: '是否确定要还原当前表格列默认配置?',
            onOk: function onOk() {
                var _ref8 = _this.props.uiorigin || {},
                    pageCode = _ref8.pageCode;

                ColumnConfigUtils.delCachedColumnConfigs({ pageCode: pageCode, tableKey: _this.props.uikey, cookieKey: _this.props.cookieKey });
                var columns = _this._renderColumns(_this.state.columnsBackup, null, _this.props);
                _this.setState({ showColumnConfigModal: false, columns: columns, scroll: _this.props.scroll });
            },
            onCancel: function onCancel() {}
        });
    }
    //表头拖拽-从样式名中获取当前列的dataIndex
    , _getIndexOfTableCol: function _getIndexOfTableCol(elem) {
        var dataIndex = '';
        var classList = elem.classList;
        for (var index = 0; index < classList.length; index++) {
            var cls = classList[index];
            var lastSeparater = cls.lastIndexOf('-');
            if (cls.indexOf(prefixTableColCls) !== -1 || cls.indexOf(prefixTableGroupColCls) !== -1) {
                return cls.substring(++lastSeparater).trim();
            }
        }
        return dataIndex;
    }
    //表头拖拽-开始拖拽表头列宽
    , _handleResizeStart: function _handleResizeStart(event) {
        var labelDom = event.currentTarget;
        var tableDom = this.tableDom;
        // by chenlizan begin 解决单表头中各列总宽度小于屏幕宽度时，拖拽宽度计算不正确的问题
        if (!this.isAnyColumnsGroup()) {
            var colWidthArr = [];
            var colArr = tableDom.querySelectorAll('.ant-table-center.ant-table-scroll colgroup col');
            tableDom.querySelectorAll('.ant-table-center.ant-table-scroll .ant-table-thead th').forEach(function (item) {
                colWidthArr.push(item.getBoundingClientRect().width + 'px');
            });
            colArr.forEach(function (item, i) {
                item.style['width'] = colWidthArr[i % colWidthArr.length];
            });
        }
        // by chenlizan end
        var currentInfo = {};
        var currentThDom = labelDom.parentNode;

        var _ref9 = currentThDom.dataset || {},
            refdataindex = _ref9.refdataindex,
            refrootdataindex = _ref9.refrootdataindex; //注意：dataset里面不区分大小写


        currentInfo.refDataIndex = refdataindex;
        currentInfo.refRootDataIndex = refrootdataindex;
        currentInfo.dataIndex = this._getIndexOfTableCol(currentThDom);

        var tableRect = DomUtils.getNodeClientRect(tableDom); //表格
        var currentThRect = DomUtils.getNodeClientRect(currentThDom); //当前的表头列
        var resizerLabelRect = DomUtils.getNodeClientRect(labelDom); //当前的伸缩label

        var resizerLineWidth = currentThRect.width;
        var resizerLineHeight = tableRect.height;
        var resizerLineLeft = resizerLabelRect.right - tableRect.left;

        this.refs.resizerLine.onLabelMouseDown(event); //开始捕获鼠标移动

        this.currentThDom = currentThDom;
        this.setState({
            visibleResizer: true,
            currentInfo: currentInfo,
            resizerLineWidth: resizerLineWidth,
            resizerLineHeight: resizerLineHeight,
            resizerLineLeft: resizerLineLeft - resizerLineWidth
        });
    }
    //表头拖拽-结束拖拽表头列宽
    , _handleResizeEnd: function _handleResizeEnd(width, info) {
        if (width) {
            width = formatUtils.formatNumber(width, 0);
        }
        var dataIndex = info.dataIndex,
            refDataIndex = info.refDataIndex,
            refRootDataIndex = info.refRootDataIndex;

        var currentThDom = this.currentThDom;
        var columns = this.state.columns;
        if (currentThDom) {
            var dragColumn = _.find(columns, ['dataIndex', dataIndex]);
            var dragColumnIndex = _.findIndex(columns, ['dataIndex', dataIndex]);
            if (!dragColumn) return;
            if (dragColumn.colSpan > 1 && dragColumn.className.indexOf('yyui-titlegroup-box') === -1) {
                for (var i = dragColumnIndex; i < dragColumnIndex + dragColumn.colSpan; i++) {
                    columns[i].width = width / dragColumn.colSpan;
                }
            } else {
                dragColumn.width = width;
            }
            //当前拖拽的列为多表头被合并的列表头时，需要同步更新titleGroup内部的对应列的宽度
            if (refRootDataIndex) {
                var refRootColumn = _.find(columns, ['dataIndex', refRootDataIndex]);
                if (!refRootColumn || !refRootColumn.titleGroup) return;
                var refColumn = TreeUtils.findWithPropName(refRootColumn.titleGroup, 'refDataIndex', refDataIndex);
                if (refColumn && refColumn.length) {
                    refColumn[0].width = width;
                    columns = this._titleGroupColumns(columns); //重新处理多表头的渲染
                }
            }
        }
        this.setState({ visibleResizer: false, columns: columns });
        // 缓存表格列配置

        var _ref10 = this.props.uiorigin || {},
            pageCode = _ref10.pageCode;

        ColumnConfigUtils.cacheAfterResize({ columns: columns, pageCode: pageCode, tableKey: this.props.uikey, cookieKey: this.props.cookieKey });
    }
    //表头拖拽-插入表头拖拽的操作点
    , _operResizerLabel: function _operResizerLabel(domThs, action) {
        if (domThs && domThs.length) {
            for (var index = 0; index < domThs.length - 1; index++) {
                //排除最后一个
                DomUtils[action](domThs[index], this._handleResizeStart);
            }
        }
    },
    componentDidMount: function componentDidMount() {
        var tableDom = ReactDOM.findDOMNode(this).querySelector('.ant-table');
        //获取需要插入拖拽点的表头（注意：排除多表头情况下的根级和树枝级的表头）
        var domThs = tableDom ? tableDom.querySelectorAll('.ant-table-thead th:not(.yyui-titlegroup-box):not(.yyui-table-anygroupcol)') : null;
        this.tableDom = tableDom;
        this.domThs = domThs;
        //是否启用表头拖拽调整列宽功能
        if (this.props.draggable) {
            this._operResizerLabel(domThs, 'addResizerLabel');
        }
        //调整勾选框列的col定义的宽度值
        if (tableDom && this.isEnableCheckable()) {
            var checkboxDoms = tableDom.querySelectorAll('.ant-table-thead .ant-table-selection-column');
            if (checkboxDoms) {
                for (var i = 0; i < checkboxDoms.length; i++) {
                    var checkboxCol = checkboxDoms[i].parentNode.parentNode.parentNode.querySelector('colgroup col:first-child');
                    checkboxCol.style.width = '60px';
                    checkboxCol.style.minWidth = '60px';
                }
            }
        }
        this._bindEvent();
        DataUtil.localSave(PAGE_NUMBER_LOCAL_KEY_EXPIRY + this._getDefaultCookieKey(), new Date(Date.now() + 1000 * 60 * 30).getTime()); //本地记录当前页码有效期
        this.syncFixedTableScrollWidth();
    },
    componentDidUpdate: function componentDidUpdate() {
        this._bindEvent();
        this.syncFixedTableScrollWidth();
    },
    componentWillUnmount: function componentWillUnmount() {
        //表头拖拽调整列宽功能，清理相关信息
        if (this.props.draggable) {
            this._operResizerLabel(this.domThs, 'removeResizerLabel');
        }
        this.tableDom = null;
        this.domThs = null;
        this.currentThDom = null;
    }
    //渲染内部行筛选输入框
    , _renderInnerFilters: function _renderInnerFilters(fixedColumns, fixed, centerColumns) {
        if (!this.isAnyColumnsInnerFilter()) return null;
        var columns = [];
        //存在左右固定列则渲染固定列的内嵌行
        if (fixed !== undefined && fixed !== false) {
            columns = fixedColumns;
        } else {
            //渲染全部列（非固定列）
            columns = centerColumns;
        }
        var colViews = [];
        _.forEach(columns, function (col) {
            var column = col;
            if (column.key == 'selection-column') {
                //勾选列
                colViews.push(React.createElement('td', { className: 'selection-column', dangerouslySetInnerHTML: { __html: '&nbsp;' } }));
            } else {
                if (column.isShow !== false) {
                    var inputView = null;
                    if (column.innerFilter === true) {
                        if (_.isFunction(column.innerFilterRender)) {
                            inputView = column.innerFilterRender(column);
                        } else {
                            inputView = React.createElement(YYInput, column.innerFilterProps);
                        }
                    }
                    var tdStyle = {};
                    if (column.width) tdStyle.width = column.width;
                    if (inputView) {
                        colViews.push(React.createElement(
                            'td',
                            { style: tdStyle },
                            inputView
                        ));
                    } else {
                        colViews.push(React.createElement('td', { dangerouslySetInnerHTML: { __html: '&nbsp;' } }));
                    }
                }
            }
        });
        return React.createElement(
            'thead',
            { className: this.className('inner-filter') },
            React.createElement(
                'tr',
                { className: this.className('inner-filter-row') },
                colViews
            )
        );
    }
    //渲染内部行合计
    , _renderInnerTotals: function _renderInnerTotals(fixedColumns, fixed, centerColumns) {
        var columns = [];
        //存在左右固定列则渲染固定列的内嵌行
        if (fixed !== undefined && fixed !== false) {
            columns = fixedColumns;
        } else {
            //渲染全部列(过滤掉固定列)
            columns = centerColumns;
        }
        // //如果存在合计列，则把其它非合计列标记为空合计emptyTotal，避免出现合计行里面单元格无数据高度未被撑起出现的错位
        // if(this.isAnyColumnsTotal()){
        //     _.forEach(columns,function(col){
        //         if(col.isShow!==false&&col.total!==true){
        //             col.emptyTotal=true;
        //         }
        //     });
        // }
        if (this.isAnyColumnsTotal()) {
            return React.createElement(YYColumnTotals, { columns: columns, dataSource: this.props.dataSource,
                totalIndex: this.props.totalIndex, totalText: this.props.totalText, totalValues: this.props.totalValues });
        } else {
            return null;
        }
    }
    //表格数据内容上下视图处理
    , _getBodyWrapper: function _getBodyWrapper(body, fixedColumns, fixed, centerColumns) {
        // var filterViews = this._renderInnerFilters(fixedColumns,fixed,centerColumns);//表格行内筛选框
        // var totalViews = this._renderInnerTotals(fixedColumns,fixed,centerColumns);//表格合计统计
        // var bodyViews = [];
        // if(filterViews)bodyViews.push(filterViews);
        // bodyViews.push(body);
        // if(totalViews)bodyViews.push(totalViews);
        // return bodyViews;
        return body;
    },
    //是否存在多表头
    isAnyColumnsGroup: function isAnyColumnsGroup() {
        if ('isAnyColumnsGroupCache' in this) {
            return this.isAnyColumnsGroupCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsGroupCache = currentColumns.some(function (column) {
            return !!(column.colSpan > 0 && !_.isEmpty(column.titleGroup));
        });
        return this.isAnyColumnsGroupCache;
    },

    //是否存在合计列
    isAnyColumnsTotal: function isAnyColumnsTotal() {
        if ('isAnyColumnsTotalCache' in this) {
            return this.isAnyColumnsTotalCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsTotalCache = currentColumns.some(function (column) {
            return !!column.total;
        });
        return this.isAnyColumnsTotalCache;
    },

    //是否存在内嵌筛选
    isAnyColumnsInnerFilter: function isAnyColumnsInnerFilter() {
        if ('isAnyColumnsInnerFilterCache' in this) {
            return this.isAnyColumnsInnerFilterCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsInnerFilterCache = currentColumns.some(function (column) {
            return !!column.innerFilter;
        });
        return this.isAnyColumnsInnerFilterCache;
    },

    //是否存在固定列
    isAnyColumnsFixed: function isAnyColumnsFixed() {
        if ('isAnyColumnsFixedCache' in this) {
            return this.isAnyColumnsFixedCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsFixedCache = currentColumns.some(function (column) {
            return !!column.fixed;
        });
        if (this.isEnableCheckable()) this.isAnyColumnsFixedCache = true; //勾选列固定
        return this.isAnyColumnsFixedCache;
    },

    //是否存在左固定列
    isAnyColumnsLeftFixed: function isAnyColumnsLeftFixed() {
        if ('isAnyColumnsLeftFixedCache' in this) {
            return this.isAnyColumnsLeftFixedCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsLeftFixedCache = currentColumns.some(function (column) {
            return column.fixed === 'left' || column.fixed === true;
        });
        if (this.isEnableCheckable()) this.isAnyColumnsFixedCache = true; //勾选列固定
        return this.isAnyColumnsLeftFixedCache;
    },

    //是否存在右固定列
    isAnyColumnsRightFixed: function isAnyColumnsRightFixed() {
        if ('isAnyColumnsRightFixedCache' in this) {
            return this.isAnyColumnsRightFixedCache;
        }
        var currentColumns = this.state.columns || [];
        this.isAnyColumnsRightFixedCache = currentColumns.some(function (column) {
            return column.fixed === 'right';
        });
        return this.isAnyColumnsRightFixedCache;
    }
    //渲染显示行序号
    ,
    renderRowNum: function renderRowNum(options) {
        var pagination = options.pagination,
            dataSource = options.dataSource,
            showRowNum = options.showRowNum;
        //显示行序号

        if (showRowNum === true && dataSource && dataSource.length > 0) {
            _.forEach(dataSource, function (row, idx) {
                var startNum = 0;
                if (pagination && dataSource.length <= pagination.pageSize) {
                    //确保为远程数据分页
                    startNum = ((pagination.current ? pagination.current : 1) - 1) * (pagination.pageSize ? pagination.pageSize : 0);
                }
                row.rowNum = startNum + 1 + idx;
            });
        }
    }
    //重置表格行高度为自适应高度
    , resetRowsHeight: function resetRowsHeight(callback) {
        if (this.refAntdTable) {
            this.refAntdTable.resetRowsHeight(callback);
        }
    }
    //同步固定列情况下部分区域滚动条出现引起的错位问题
    ,
    syncFixedTableScrollWidth: function syncFixedTableScrollWidth() {
        var tableDom = ReactDOM.findDOMNode(this);
        var tableContentDom = tableDom.querySelector('.ant-table-content');
        var tableBottomTableDom = tableDom.querySelector('.ant-table-center .ant-table-bottom .ant-table-fixed');
        var tableFixedRight = tableDom.querySelector('.ant-table-fixed-right');
        var centerBodyDom = tableDom.querySelector('.ant-table-center .ant-table-body');
        var centerHeadTableDom = tableDom.querySelector('.ant-table-center .ant-table-header table');
        var bodyInnerDoms = tableDom.querySelectorAll('.ant-table-body-outer .ant-table-body-inner');
        if (!this._scrollbarWidth) this._scrollbarWidth = measureScrollbar();
        var scrollbarWidth = this._scrollbarWidth;
        var hasCenterScrollY = !!(centerBodyDom.scrollHeight > centerBodyDom.clientHeight); //中间区域是否存在垂直滚动条
        var hasCenterScrollX = !!(centerBodyDom.scrollWidth > centerBodyDom.clientWidth); //中间区域存在水平滚动条
        //解决存在右侧固定列,中间区域垂直滚动条需要隐藏显示的问题
        if (hasCenterScrollY && this.isAnyColumnsRightFixed()) {
            centerBodyDom.style.marginRight = '-' + scrollbarWidth + 'px';
        } else {
            centerBodyDom.style.marginRight = 0;
        }
        //解决中间区域存在水平滚动条，左右固定区域无法跟其对齐的问题
        if (bodyInnerDoms && bodyInnerDoms.length) {
            _.forEach(bodyInnerDoms, function (bodyInnerDom) {
                if (hasCenterScrollX) {
                    bodyInnerDom.style.paddingBottom = scrollbarWidth + 'px';
                } else {
                    bodyInnerDom.style.paddingBottom = 0;
                }
            });
        }
        //解决中间存在水平滚动条头部区域无法对齐的问题
        if (centerHeadTableDom) {
            var paddingWidth = 0;
            if (hasCenterScrollY && hasCenterScrollX || hasCenterScrollY && !tableFixedRight) paddingWidth = paddingWidth + scrollbarWidth;
            centerHeadTableDom.style.paddingRight = paddingWidth + 'px';
        }
        //统计数据表格和中间数据表格对齐
        if (tableBottomTableDom) {
            var _paddingWidth = 0;
            if (hasCenterScrollY && hasCenterScrollX || hasCenterScrollY && !tableFixedRight) _paddingWidth = _paddingWidth + scrollbarWidth;
            tableBottomTableDom.style.paddingRight = _paddingWidth + 'px';
        }
        //为表格追加是否存在滚动条的样式标识
        if (tableContentDom) {
            if (hasCenterScrollX) {
                if (!tableContentDom.classList.contains('has-scroll-x')) tableContentDom.classList.add('has-scroll-x');
            } else {
                tableContentDom.classList.remove('has-scroll-x');
            }
            if (hasCenterScrollY) {
                if (!tableContentDom.classList.contains('has-scroll-y')) tableContentDom.classList.add('has-scroll-y');
            } else {
                tableContentDom.classList.remove('has-scroll-y');
            }
        }
    }
    // //是否启用固定表头
    // _isUseFixedHeader:function(){
    //     var anyFixed = this.isAnyColumnsFixed();
    //     var anyTitleGroup = this.isAnyColumnsGroup();
    //     //存在固定列+多表头则默认启用固定表头
    //     var useFixedHeader = anyFixed&&anyTitleGroup?true:this.props.useFixedHeader;
    //     return useFixedHeader;
    // }
    //滚动区域的配置
    , _getScroll: function _getScroll() {
        return {
            x: true,
            y: this.state.scroll ? this.state.scroll.y == undefined ? false : this.state.scroll.y : false
        };
    }
    // 是否自动开启树形结构选中联动
    , _autoSelect: function _autoSelect() {
        return this.props.autoSelect;
    },
    _onChange: function _onChange(pagination, filters, sorter) {
        for (var i = 1; i <= this.refTitleGroupIndex; i++) {
            if (this['refTitleGroup-' + i]) this['refTitleGroup-' + i].setColOrderState(sorter.column || null, sorter.order || null);
        }
        if (_.isFunction(this.props.onChange)) {
            this.props.onChange(pagination, filters, sorter);
        }
    },
    render: function render() {
        var _this4 = this;

        var locale = {};
        var _props3 = this.props,
            emptyView = _props3.emptyView,
            dataSource = _props3.dataSource,
            showRowNum = _props3.showRowNum,
            rowBreak = _props3.rowBreak;

        var cls = this.className();
        if (rowBreak === true) {
            cls = cls + ' row-break';
        }
        emptyView ? locale.emptyText = emptyView : null;
        var pagination = this.getDefaultPagination();
        //渲染行序号
        this.renderRowNum({ pagination: pagination, dataSource: dataSource, showRowNum: showRowNum });
        var tableViews = [];
        tableViews.push(React.createElement(Table, _extends({}, this.props, {
            ref: function ref(t) {
                _this4.refAntdTable = t;
            },
            dataSource: dataSource,
            rowClassName: this._rowClassName.bind(this),
            onRowClick: this._onRowClick,
            onChange: this._onChange.bind(this),
            className: cls,
            columns: this.state.columns,
            locale: locale,
            scroll: this._getScroll(),
            selectionColumnFixed: true
            // useFixedHeader={this._isUseFixedHeader()}
            , getBodyWrapper: this._getBodyWrapper,
            getInnerFilters: this._renderInnerFilters,
            getInnerTotals: this._renderInnerTotals,
            rowSelection: this.getDefaultRowSelection(),
            pagination: pagination,
            autoSelect: this._autoSelect()
        })));
        tableViews.push(React.createElement(YYPopMenu, { ref: function ref(my) {
                return _this4._tablecontextmenu = my;
            }, items: [{ key: 'tableContextMenuConfigColumns', icon: 'setting', text: '自定义列' }], onMenuClick: this._onContextMenuClick.bind(this) }));
        if (this.props.draggable) {
            tableViews.push(React.createElement(ResizerLine, {
                ref: 'resizerLine',
                left: this.state.resizerLineLeft,
                height: this.state.resizerLineHeight,
                visible: this.state.visibleResizer,
                onResizeEnd: this._handleResizeEnd,
                currentInfo: this.state.currentInfo,
                initialWidth: this.state.resizerLineWidth
            }));
        }
        // BEGIN xg modified 增加表格配置列组件
        if (this.state.showColumnConfigModal) {
            var _ref11 = this.props.uiorigin || {},
                pageCode = _ref11.pageCode;

            var options = { columns: this.state.columnsBackup, pageCode: pageCode, tableKey: this.props.uikey, cookieKey: this.props.cookieKey };
            var columns = ColumnConfigUtils.showColumnConfig(options);
            var isTitleGroup = _.filter(columns, function (column) {
                return column.titleGroup && column.titleGroup.length;
            });
            tableViews.push(React.createElement(YYColumnConfig, _extends({}, this.props, { visible: this.state.showColumnConfigModal, columns: columns, scroll: this._getScroll(),
                onOk: this._onColumnConfigDone, onCancel: this._onColumnConfigCancel,
                onRevert: this._onColumnConfigRevert, isTitleGroup: isTitleGroup })));
        }
        // END
        return React.createElement(
            'div',
            { className: this.className('wrapper') },
            tableViews
        );
    }
});

module.exports = YYTable;